messagingapp/msgui/conversationview/inc/msgconversationwidget.h
changeset 34 84197e66a4bd
parent 31 ebfee66fde93
child 43 35b64624a9e7
--- a/messagingapp/msgui/conversationview/inc/msgconversationwidget.h	Fri Jun 04 10:25:39 2010 +0100
+++ b/messagingapp/msgui/conversationview/inc/msgconversationwidget.h	Fri Jun 11 13:35:48 2010 +0300
@@ -20,6 +20,7 @@
 
 // SYSTEM INCLUDES
 #include <hbwidget.h>
+#include <HbIcon>
 
 // FORWORD DECLARATIONS
 class HbFrameItem;
@@ -86,10 +87,10 @@
     void setBodyText(const QString &bodyText);
 
     /**
      * Set preview icon path for this widget
      * @param QString
      */
-    void setPreviewIconPath(const QString& filePath,int msgId);
+    void setPreviewIcon(HbIcon& icon);
 
     /**
      * Set priority property
@@ -86,10 +87,10 @@
 
     /**
-     * Set preview icon path for this widget
-     * @param QString
+     * Set preview icon for this widget
+     * @param HbIcon, preview-icon
      */